@@ -44,6 +44,7 @@ from airflow.utils.state import State
 from tests_common.test_utils import db
 from tests_common.test_utils.config import conf_vars
 from tests_common.test_utils.dag import sync_dag_to_db
+from tests_common.test_utils.taskinstance import create_task_instance
 from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS, AIRFLOW_V_3_1_PLUS, AIRFLOW_V_3_2_PLUS
 
 if AIRFLOW_V_3_0_PLUS:
@@ -92,6 +93,8 @@ def _prepare_app(broker_url=None, execute=None):
     test_execute = test_app.task(execute)
     patch_app = mock.patch.object(celery_executor_utils, "app", test_app)
     patch_execute = mock.patch.object(celery_executor_utils, execute_name, test_execute)
+    # Patch factory function so CeleryExecutor instances get the test app
+    patch_factory = mock.patch.object(celery_executor_utils, "create_celery_app", return_value=test_app)
 
     backend = test_app.backend
 
@@ -104,7 +107,7 @@ def _prepare_app(broker_url=None, execute=None):
         session = backend.ResultSession()
         session.close()
 
-    with patch_app, patch_execute:
+    with patch_app, patch_execute, patch_factory:
         try:
             yield test_app
         finally:
@@ -137,16 +140,16 @@ class TestCeleryExecutor:
         parallelism = 50
         team_name = "test_team"
 
-        if AIRFLOW_V_3_1_PLUS:
-            # team_name was added in Airflow 3.1
+        if AIRFLOW_V_3_2_PLUS:
+            # Multi-team support with ExecutorConf requires Airflow 3.2+
             executor = celery_executor.CeleryExecutor(parallelism=parallelism, team_name=team_name)
         else:
             executor = celery_executor.CeleryExecutor(parallelism)
 
         assert executor.parallelism == parallelism
 
-        if AIRFLOW_V_3_1_PLUS:
-            # team_name was added in Airflow 3.1
+        if AIRFLOW_V_3_2_PLUS:
+            # Multi-team support with ExecutorConf requires Airflow 3.2+
             assert executor.team_name == team_name
             assert executor.conf.team_name == team_name
 
@@ -229,7 +232,7 @@ class TestCeleryExecutor:
         if AIRFLOW_V_3_0_PLUS:
             sync_dag_to_db(dag)
             dag_version = DagVersion.get_latest_version(dag.dag_id)
-            key1 = TaskInstance(task=task_1, run_id=None, dag_version_id=dag_version.id)
+            key1 = create_task_instance(task=task_1, run_id=None, dag_version_id=dag_version.id)
         else:
             key1 = TaskInstance(task=task_1, run_id=None)
         tis = [key1]
@@ -250,8 +253,8 @@ class TestCeleryExecutor:
         if AIRFLOW_V_3_0_PLUS:
             sync_dag_to_db(dag)
             dag_version = DagVersion.get_latest_version(dag.dag_id)
-            ti1 = TaskInstance(task=task_1, run_id=None, dag_version_id=dag_version.id)
-            ti2 = TaskInstance(task=task_2, run_id=None, dag_version_id=dag_version.id)
+            ti1 = create_task_instance(task=task_1, run_id=None, dag_version_id=dag_version.id)
+            ti2 = create_task_instance(task=task_2, run_id=None, dag_version_id=dag_version.id)
         else:
             ti1 = TaskInstance(task=task_1, run_id=None)
             ti2 = TaskInstance(task=task_2, run_id=None)
@@ -294,7 +297,7 @@ class TestCeleryExecutor:
         if AIRFLOW_V_3_0_PLUS:
             sync_dag_to_db(dag)
             dag_version = DagVersion.get_latest_version(task.dag.dag_id)
-            ti = TaskInstance(task=task, run_id=None, dag_version_id=dag_version.id)
+            ti = create_task_instance(task=task, run_id=None, dag_version_id=dag_version.id)
         else:
             ti = TaskInstance(task=task, run_id=None)
         ti.external_executor_id = "231"
@@ -328,7 +331,7 @@ class TestCeleryExecutor:
         if AIRFLOW_V_3_0_PLUS:
             sync_dag_to_db(dag)
             dag_version = DagVersion.get_latest_version(task.dag.dag_id)
-            ti = TaskInstance(task=task, run_id=None, dag_version_id=dag_version.id)
+            ti = create_task_instance(task=task, run_id=None, dag_version_id=dag_version.id)
         else:
             ti = TaskInstance(task=task, run_id=None)
         ti.external_executor_id = "231"
@@ -352,18 +355,23 @@ class TestCeleryExecutor:
         mock_fail.assert_not_called()
 
     @conf_vars({("celery", "result_backend_sqlalchemy_engine_options"): '{"pool_recycle": 1800}'})
-    @mock.patch("celery.Celery")
-    def test_result_backend_sqlalchemy_engine_options(self, mock_celery):
+    def test_result_backend_sqlalchemy_engine_options(self):
         import importlib
 
-        # reload celery conf to apply the new config
-        importlib.reload(default_celery)
-        # reload celery_executor_utils to recreate the celery app with new config
-        importlib.reload(celery_executor_utils)
+        # Scope the mock using context manager so we can clean up afterward
+        with mock.patch("celery.Celery") as mock_celery:
+            # reload celery conf to apply the new config
+            importlib.reload(default_celery)
+            # reload celery_executor_utils to recreate the celery app with new config
+            importlib.reload(celery_executor_utils)
 
-        call_args = mock_celery.call_args.kwargs.get("config_source")
-        assert "database_engine_options" in call_args
-        assert call_args["database_engine_options"] == {"pool_recycle": 1800}
+            call_args = mock_celery.call_args.kwargs.get("config_source")
+            assert "database_engine_options" in call_args
+            assert call_args["database_engine_options"] == {"pool_recycle": 1800}
+
+        # Clean up: reload modules with real Celery to restore clean state for subsequent tests
+        importlib.reload(default_celery)
+        importlib.reload(celery_executor_utils)
 
 
 def test_operation_timeout_config():
@@ -466,3 +474,216 @@ def test_celery_extra_celery_config_loaded_from_string():
     # reload celery conf to apply the new config
     importlib.reload(default_celery)
     assert default_celery.DEFAULT_CELERY_CONFIG["worker_max_tasks_per_child"] == 10
+
+
+@conf_vars({("celery_result_backend_transport_options", "sentinel_kwargs"): '{"password": "redis_password"}'})
+def test_result_backend_sentinel_kwargs_loaded_from_string():
+    """Test that sentinel_kwargs for result backend transport options is correctly parsed."""
+    import importlib
+
+    # reload celery conf to apply the new config
+    importlib.reload(default_celery)
+    assert "result_backend_transport_options" in default_celery.DEFAULT_CELERY_CONFIG
+    assert default_celery.DEFAULT_CELERY_CONFIG["result_backend_transport_options"]["sentinel_kwargs"] == {
+        "password": "redis_password"
+    }
+
+
+@conf_vars({("celery_result_backend_transport_options", "master_name"): "mymaster"})
+def test_result_backend_master_name_loaded():
+    """Test that master_name for result backend transport options is correctly loaded."""
+    import importlib
+
+    # reload celery conf to apply the new config
+    importlib.reload(default_celery)
+    assert "result_backend_transport_options" in default_celery.DEFAULT_CELERY_CONFIG
+    assert (
+        default_celery.DEFAULT_CELERY_CONFIG["result_backend_transport_options"]["master_name"] == "mymaster"
+    )
+
+
+@conf_vars(
+    {
+        ("celery_result_backend_transport_options", "sentinel_kwargs"): '{"password": "redis_password"}',
+        ("celery_result_backend_transport_options", "master_name"): "mymaster",
+    }
+)
+def test_result_backend_transport_options_with_multiple_options():
+    """Test that multiple result backend transport options are correctly loaded."""
+    import importlib
+
+    # reload celery conf to apply the new config
+    importlib.reload(default_celery)
+    result_backend_opts = default_celery.DEFAULT_CELERY_CONFIG["result_backend_transport_options"]
+    assert result_backend_opts["sentinel_kwargs"] == {"password": "redis_password"}
+    assert result_backend_opts["master_name"] == "mymaster"
+
+
+@conf_vars({("celery_result_backend_transport_options", "sentinel_kwargs"): "invalid_json"})
+def test_result_backend_sentinel_kwargs_invalid_json():
+    """Test that invalid JSON in sentinel_kwargs raises an error."""
+    import importlib
+
+    from airflow.providers.common.compat.sdk import AirflowException
+
+    with pytest.raises(
+        AirflowException, match="sentinel_kwargs.*should be written in the correct dictionary format"
+    ):
+        importlib.reload(default_celery)
+
+
+@conf_vars({("celery_result_backend_transport_options", "sentinel_kwargs"): '"not_a_dict"'})
+def test_result_backend_sentinel_kwargs_not_dict():
+    """Test that non-dict sentinel_kwargs raises an error."""
+    import importlib
+
+    from airflow.providers.common.compat.sdk import AirflowException
+
+    with pytest.raises(
+        AirflowException, match="sentinel_kwargs.*should be written in the correct dictionary format"
+    ):
+        importlib.reload(default_celery)
+
+
+@conf_vars(
+    {
+        ("celery", "result_backend"): "sentinel://sentinel1:26379;sentinel://sentinel2:26379",
+        ("celery_result_backend_transport_options", "sentinel_kwargs"): '{"password": "redis_pass"}',
+        ("celery_result_backend_transport_options", "master_name"): "mymaster",
+    }
+)
+def test_result_backend_sentinel_full_config():
+    """Test full Redis Sentinel configuration for result backend."""
+    import importlib
+
+    # reload celery conf to apply the new config
+    importlib.reload(default_celery)
+
+    assert default_celery.DEFAULT_CELERY_CONFIG["result_backend"] == (
+        "sentinel://sentinel1:26379;sentinel://sentinel2:26379"
+    )
+    result_backend_opts = default_celery.DEFAULT_CELERY_CONFIG["result_backend_transport_options"]
+    assert result_backend_opts["sentinel_kwargs"] == {"password": "redis_pass"}
+    assert result_backend_opts["master_name"] == "mymaster"
+
+
+@pytest.mark.skipif(not AIRFLOW_V_3_2_PLUS, reason="Multi-team support requires Airflow 3.2+")
+class TestMultiTeamCeleryExecutor:
+    """Test multi-team functionality in CeleryExecutor."""
+
+    def setup_method(self) -> None:
+        db.clear_db_runs()
+        db.clear_db_jobs()
+
+    def teardown_method(self) -> None:
+        db.clear_db_runs()
+        db.clear_db_jobs()
+
+    @conf_vars(
+        {
+            ("celery", "broker_url"): "redis://global:6379/0",
+            ("operators", "default_queue"): "global_queue",
+        }
+    )
+    def test_multi_team_isolation_and_task_routing(self, monkeypatch):
+        """
+        Test multi-team executor isolation and correct task routing.
+
+        Verifies:
+        - Each executor has isolated Celery app and config
+        - Tasks are routed through team-specific apps (_process_tasks/_process_workloads)
+        - Backward compatibility with global executor
+        """
+        # Set up team-specific config via environment variables
+        monkeypatch.setenv("AIRFLOW__TEAM_A___CELERY__BROKER_URL", "redis://team-a:6379/0")
+        monkeypatch.setenv("AIRFLOW__TEAM_A___OPERATORS__DEFAULT_QUEUE", "team_a_queue")
+        monkeypatch.setenv("AIRFLOW__TEAM_B___CELERY__BROKER_URL", "redis://team-b:6379/0")
+        monkeypatch.setenv("AIRFLOW__TEAM_B___OPERATORS__DEFAULT_QUEUE", "team_b_queue")
+
+        # Reload config to pick up environment variables
+        from airflow import configuration
+
+        configuration.conf.read_dict({}, source="test")
+
+        # Create executors with different team configs
+        team_a_executor = CeleryExecutor(parallelism=2, team_name="team_a")
+        team_b_executor = CeleryExecutor(parallelism=3, team_name="team_b")
+        global_executor = CeleryExecutor(parallelism=4)
+
+        # Each executor has its own Celery app (critical for isolation)
+        assert team_a_executor.celery_app is not team_b_executor.celery_app
+        assert team_a_executor.celery_app is not global_executor.celery_app
+
+        # Team-specific broker URLs are used
+        assert "team-a" in team_a_executor.celery_app.conf.broker_url
+        assert "team-b" in team_b_executor.celery_app.conf.broker_url
+        assert "global" in global_executor.celery_app.conf.broker_url
+
+        # Team-specific queues are used
+        assert team_a_executor.celery_app.conf.task_default_queue == "team_a_queue"
+        assert team_b_executor.celery_app.conf.task_default_queue == "team_b_queue"
+        assert global_executor.celery_app.conf.task_default_queue == "global_queue"
+
+        # Each executor has its own BulkStateFetcher with correct app
+        assert team_a_executor.bulk_state_fetcher.celery_app is team_a_executor.celery_app
+        assert team_b_executor.bulk_state_fetcher.celery_app is team_b_executor.celery_app
+
+        # Executors have isolated internal state
+        assert team_a_executor.tasks is not team_b_executor.tasks
+        assert team_a_executor.running is not team_b_executor.running
+        assert team_a_executor.queued_tasks is not team_b_executor.queued_tasks
+
+    @conf_vars({("celery", "broker_url"): "redis://global:6379/0"})
+    @mock.patch("airflow.providers.celery.executors.celery_executor.CeleryExecutor._send_tasks")
+    def test_task_routing_through_team_specific_app(self, mock_send_tasks, monkeypatch):
+        """
+        Test that _process_tasks and _process_workloads pass the correct team_name for task routing.
+
+        With the ProcessPoolExecutor approach, we pass team_name instead of task objects to avoid
+        pickling issues. The subprocess reconstructs the team-specific Celery app from the team_name.
+        """
+        # Set up team A config
+        monkeypatch.setenv("AIRFLOW__TEAM_A___CELERY__BROKER_URL", "redis://team-a:6379/0")
+
+        team_a_executor = CeleryExecutor(parallelism=2, team_name="team_a")
+
+        if AIRFLOW_V_3_0_PLUS:
+            from airflow.executors.workloads import ExecuteTask
+            from airflow.models.taskinstancekey import TaskInstanceKey
+
+            # Create mock workload
+            mock_ti = mock.Mock()
+            mock_ti.key = TaskInstanceKey("dag", "task", "run", 1)
+            mock_ti.queue = "test_queue"
+            mock_workload = mock.Mock(spec=ExecuteTask)
+            mock_workload.ti = mock_ti
+
+            # Process workload through team A executor
+            team_a_executor._process_workloads([mock_workload])
+
+            # Verify _send_tasks received the correct team_name
+            assert mock_send_tasks.called
+            task_tuples = mock_send_tasks.call_args[0][0]
+            team_name_from_call = task_tuples[0][3]  # 4th element is now team_name
+
+            # Critical: team_name is passed so subprocess can reconstruct the correct app
+            assert team_name_from_call == "team_a"
+        else:
+            from airflow.models.taskinstancekey import TaskInstanceKey
+
+            # Test V2 path with execute_command
+            mock_key = TaskInstanceKey("dag", "task", "run", 1)
+            mock_command = ["airflow", "tasks", "run", "dag", "task"]
+            mock_queue = "test_queue"
+
+            # Process task through team A executor
+            team_a_executor._process_tasks([(mock_key, mock_command, mock_queue, None)])
+
+            # Verify _send_tasks received team A's execute_command task
+            assert mock_send_tasks.called
+            task_tuples = mock_send_tasks.call_args[0][0]
+            task_from_call = task_tuples[0][3]  # 4th element is the task (V2 still uses task object)
+
+            # Critical: task belongs to team A's app, not module-level app
+            assert task_from_call.app is team_a_executor.celery_app
+            assert task_from_call.name == "execute_command"
